@@ -3,12 +3,12 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.60';
+our $VERSION = '0.6001';
 
 use warnings;
 use strict;
 
-use parent qw(Graph);
+use parent qw( Graph );
 
 use Carp qw( croak );
 use Readonly;
@@ -108,12 +108,6 @@ sub _from_hash {
 }
 
 
-sub get_weight {
-    my $self = shift;
-    return $self->get_cost(@_);
-}
-
-
 sub get_cost {
     my ($self, $v, $attr) = @_;
     croak 'ERROR: No vertex given to get_cost()' unless defined $v;
@@ -132,11 +126,13 @@ sub get_cost {
 sub vertex_span {
     my ($self, $attr) = @_;
 
+    # Get the cost of each vertex
     my $mass = {};
     for my $vertex ( $self->vertices ) {
         $mass->{$vertex} = $self->get_cost($vertex, $attr);
     }
 
+    # Find the smallest & biggest costs
     my ($smallest, $biggest);
     for my $vertex ( keys %$mass ) {
         my $current = $mass->{$vertex};
@@ -148,6 +144,7 @@ sub vertex_span {
         }
     }
 
+    # Collect the lightest & heaviest vertices
     my ($lightest, $heaviest) = ([], []);
     for my $vertex ( keys %$mass ) {
         push @$lightest, $vertex if $mass->{$vertex} == $smallest;
@@ -161,11 +158,13 @@ sub vertex_span {
 sub edge_span {
     my ($self, $attr) = @_;
 
+    # Get the cost of each edge
     my $mass = {};
     for my $edge ( $self->edges ) {
         $mass->{ $edge->[0] . '_' . $edge->[1] } = $self->get_cost($edge, $attr);
     }
 
+    # Find the smallest & biggest costs
     my ($smallest, $biggest);
     for my $edge ( keys %$mass ) {
         my $current = $mass->{$edge};
@@ -177,6 +176,7 @@ sub edge_span {
         }
     }
 
+    # Collect the lightest & heaviest edges
     my ($lightest, $heaviest) = ([], []);
     for my $edge ( sort keys %$mass ) {
         my $arrayref = [ split /_/, $edge ];
@@ -217,7 +217,7 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.60
+version 0.6001
 
 =head1 SYNOPSIS
 
@@ -251,9 +251,9 @@ version 0.60
  $gw->populate(
     {
         0 => { label => 'A', 1=>0.4, 3=>0.6 }, # Vertex A with 2 edges, weight 1
-        1 => { label => 'B', 0=>0.3, 2=>0.7 }, # Vertex B "    2 "
-        2 => { label => 'C', 0=>0.5, 2=>0.5 }, # Vertex C "    2 "
-        3 => { label => 'D', 0=>0.2, 1=>0.8 }, # Vertex D "    2 "
+        1 => { label => 'B', 0=>0.3, 2=>0.7 }, # "      B "    2 "
+        2 => { label => 'C', 0=>0.5, 2=>0.5 }, # "      C "    2 "
+        3 => { label => 'D', 0=>0.2, 1=>0.8 }, # "      D "    2 "
     },
     $attr
  );
@@ -305,22 +305,6 @@ The optional edge C<attribute> argument is a string with the default "weight."
 Multiple attributes may be applied to a graph, thereby layering and increasing
 the overall dimension.
 
-Examples of vertices in array reference form:
-
-  []      1 vertex with no edges.
-  [0]     1 vertex with no edges.
-  [1]     1 vertex and 1 edge to itself, weight 1.
-  [0,1]   2 vertices and 1 edge, weight 1.
-  [1,0,9] 3 vertices and 2 edges having, weight 10.
-  [1,2,3] 3 vertices and 3 edges having, weight 6.
-
-=head2 get_weight()
-
-  $w = $gw->get_weight($vertex);
-  $w = $gw->get_weight([$vertex, $neighbor]);
-
-Return the weight for the vertex or edge.
-
 =head2 get_cost()
 
   $c = $gw->get_cost($vertex);
